@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 import argparse
 import collections
+import glob
 import json
 import os
 import re
@@ -43,7 +44,7 @@ class DebugStream(QtWidgets.QWidget):
         super(DebugStream, self).__init__()
         self.debugDevice = debugDevice
         self.debugWidget = debugWidget
-        self.name = "Stream" + str(streamID)
+        self.name = None
         self.widget = msgtools.lib.gui.TreeWidget()
         self.widget.debugStream = self
         self.streamID = streamID
@@ -69,14 +70,14 @@ class DebugStream(QtWidgets.QWidget):
 
         # add it to the tab widget, so the user can see it
         added = 0
-        tabName = debugDevice.name+", " + self.name
+        self.fullName = debugDevice.name+", " + "Stream" + str(streamID)
         for index in range(0,self.debugWidget.tabWidget.count()):
-            if(tabName < self.debugWidget.tabWidget.tabText(index)):
-                self.debugWidget.tabWidget.insertTab(index, self.widget, tabName)
+            if(self.fullName < self.debugWidget.tabWidget.tabText(index)):
+                self.debugWidget.tabWidget.insertTab(index, self.widget, self.fullName)
                 added = 1
                 break
         if not added:
-            self.debugWidget.tabWidget.addTab(self.widget, tabName)
+            self.debugWidget.tabWidget.addTab(self.widget, self.fullName)
 
         # add table header, one column for each message field
         tableHeader = []
@@ -95,19 +96,30 @@ class DebugStream(QtWidgets.QWidget):
     def clear(self):
         self.widget.clear()
 
-    def Rename(self, deviceName, streamName=None):
-        if streamName == None:
-            # if we're renaming because we just learned the deviceName, we ought to query the stream name.
-            self.getStreamInfo()
+    def Rename(self, deviceName, new_stream_name=None):
+        if new_stream_name == None:
+            # if we're renaming because we just learned the deviceName,
+            # get the stream name if it's not yet set.
+            if self.name == None:
+                self.getStreamInfo()
         else:
             # if we got the stream name, then set it.
-            self.name = streamName
-        newName = deviceName + ", " + self.name
-        tabIndex = self.debugWidget.tabWidget.indexOf(self.widget)
-        if tabIndex < 0:
-            self.statusUpdate.emit("Warning!  Couldn't find debug tab for device " + route + " stream " + str(streamID))
+            if self.name != new_stream_name:
+                self.name = new_stream_name
+        
+        # If the name changed, update the GUI.
+        if self.name:
+            stream_name = self.name
         else:
-            self.debugWidget.tabWidget.setTabText(tabIndex, newName)
+            stream_name = "Stream" + str(self.streamID)
+        newName = deviceName + ", " + stream_name
+        if newName != self.fullName:
+            self.fullName = newName
+            tabIndex = self.debugWidget.tabWidget.indexOf(self.widget)
+            if tabIndex < 0:
+                self.statusUpdate.emit("Warning!  Couldn't find debug tab for device " + route + " stream " + str(streamID))
+            else:
+                self.debugWidget.tabWidget.setTabText(tabIndex, newName)
 
     def debugThresholdChanged(self):
         action = self.sender()
@@ -274,7 +286,13 @@ class DebugDevice(QtWidgets.QWidget):
         self.dictionary = []
         nextId = 0
         try:
-            with open(filename, 'r') as formatStringFile:
+            all_filenames = glob.glob(filename)
+            if len(all_filenames) == 0:
+                self.statusUpdate.emit("ERROR! No files match %s" % (filename))
+            elif len(all_filenames) > 1:
+                self.statusUpdate.emit("ERROR! Multiple files %s match %s" % (all_filenames, filename))
+            specific_filename = all_filenames[0]
+            with open(specific_filename, 'r') as formatStringFile:
                 lines = formatStringFile.read().splitlines()
                 for line in lines:
                     matchObj = re.search( r'(\d+).*:\s*"([^"]*)", (.*), (\d+)', line)
@@ -297,15 +315,21 @@ class DebugDevice(QtWidgets.QWidget):
     def ProcessMessage(self, msg):
         if type(msg) == self.debugWidget.deviceInfoMsg:
             dictionaryID = ""
-            for i in range(msg.GetDebugStringDictionaryID.count):
-                dictionaryID += '{:02x}'.format(msg.GetDebugStringDictionaryID(i))
-            if dictionaryID != self.dictionaryID:
-                if "00000000000000000000000000000000" in dictionaryID:
-                    self.statusUpdate.emit("ERROR!  Dictionary ID %s invalid, being ignored" % self.statusUpdate.emit)
-                else:
-                    # If dictionary ID changed or wasn't previously set, load the dictionary.
-                    self.ReadDictionary("%s/PrintfDictionaries/%s.json" % (Messaging.objdir, dictionaryID))
-
+            try:
+                for i in range(msg.GetDebugStringDictionaryID.count):
+                    dictionaryID += '{:02x}'.format(msg.GetDebugStringDictionaryID(i))
+                if msg.GetDebugStringDictionaryID.count < 16:
+                    dictionaryID = "*%s*" % dictionaryID
+                if dictionaryID != self.dictionaryID:
+                    if "0000000000000000" in dictionaryID:
+                        self.statusUpdate.emit("ERROR!  Dictionary ID %s invalid, being ignored" % self.statusUpdate.emit)
+                    else:
+                        # If dictionary ID changed or wasn't previously set, load the dictionary.
+                        self.ReadDictionary("%s/PrintfDictionaries/%s.json" % (Messaging.objdir, dictionaryID))
+            except struct.error:
+                print("Cannot access DebugStringDictionaryID in %s message %s" % (self.debugWidget.deviceInfoMsg.MsgName(), msg))
+                return
+            # If we get the deviceinfo, rename all the streams.
             try:
                 deviceName = msg.GetDeviceName()
             except AttributeError:
