@@ -383,6 +383,9 @@ or specify that directory with --msgdir=PATH''')
                 value = fieldInfo.get(msg)
             else:
                 value = fieldInfo.get(msg, index)
+            if "hex" == fieldInfo.units.lower():
+                digits = fieldInfo.size*2
+                value = ("0x%0"+str(digits)+"X") % (value)
         except struct.error:
             value = "UNALLOCATED"
         return value
