@@ -3,8 +3,9 @@ import struct
 import ctypes
 from msgtools.lib.messaging import *
 import msgtools.lib.messaging as msg
+from msgtools.lib.message import Message
 
-class UnknownMsg :
+class UnknownMsg(Message):
     MSG_OFFSET = Messaging.hdrSize
     
     def __init__(self, messageBuffer):
@@ -13,12 +14,6 @@ class UnknownMsg :
 
         self.hdr = Messaging.hdr(messageBuffer)
 
-    # This is a hack to make UnknownMsgs appear to have a ID property
-    def __getattr__(self, attr):
-        if attr == 'ID':
-            return self.hdr.GetMessageID()
-        return getattr(self, attr)
-
     def rawBuffer(self):
         # this is a trick to get us to store a copy of a pointer to a buffer, rather than making a copy of the buffer
         return self.msg_buffer_wrapper["msg_buffer"]
@@ -28,14 +23,16 @@ class UnknownMsg :
         return "Unknown_"+id
 
     @msg.offset('0')
-    @msg.size('64')
+    @msg.count('64')
+    @msg.size('1')
     def GetRawData(self, index):
         """"""
         value = struct.unpack_from('>B', self.rawBuffer(), UnknownMsg.MSG_OFFSET + index)[0]
         return hex(value)
         
     @msg.offset('0')
-    @msg.size('64')
+    @msg.count('64')
+    @msg.size('1')
     def SetRawData(self, value, index):
         """"""
         struct.pack_into('>B', self.rawBuffer(), UnknownMsg.MSG_OFFSET + index, value)
